SessionStore

Struct SessionStore 

pub struct SessionStore { /* private fields */ }
Session store for SRBN persistence

Implementations

Source

impl SessionStore

pub fn new() -> Result<SessionStore, Error>

Create a new session store with default path

pub fn open(path: &PathBuf) -> Result<SessionStore, Error>

Open a session store at the given path

pub fn default_db_path() -> Result<PathBuf, Error>

Get the default database path (~/.local/share/perspt/perspt.db or similar)

pub fn create_session(&self, session: &SessionRecord) -> Result<(), Error>

Create a new session

pub fn update_merkle_root( &self, session_id: &str, merkle_root: &[u8], ) -> Result<(), Error>

Update session merkle root

pub fn record_node_state(&self, record: &NodeStateRecord) -> Result<(), Error>

Record node state

pub fn record_energy(&self, record: &EnergyRecord) -> Result<(), Error>

Record energy measurement

pub fn calculate_hash(content: &[u8]) -> Vec<u8>

Calculate Merkle hash for content

pub fn get_session( &self, session_id: &str, ) -> Result<Option<SessionRecord>, Error>

Get session by ID

pub fn get_session_dir(&self, session_id: &str) -> Result<PathBuf, Error>

Get the directory for session artifacts (~/.local/share/perspt/sessions/<id>)

pub fn create_session_dir(&self, session_id: &str) -> Result<PathBuf, Error>

Ensure a session directory exists and return the path

pub fn get_energy_history( &self, session_id: &str, node_id: &str, ) -> Result<Vec<EnergyRecord>, Error>

Get energy history for a node (query)

pub fn list_recent_sessions( &self, limit: usize, ) -> Result<Vec<SessionRecord>, Error>

List recent sessions (newest first)

pub fn get_node_states( &self, session_id: &str, ) -> Result<Vec<NodeStateRecord>, Error>

Get all node states for a session

pub fn update_session_status( &self, session_id: &str, status: &str, ) -> Result<(), Error>

Update session status

pub fn record_llm_request(&self, record: &LlmRequestRecord) -> Result<(), Error>

Record an LLM request/response

pub fn get_llm_requests( &self, session_id: &str, ) -> Result<Vec<LlmRequestRecord>, Error>

Get LLM requests for a session

pub fn count_all_llm_requests(&self) -> Result<i64, Error>

Count all LLM requests in the database (for debugging)

pub fn get_all_llm_requests( &self, limit: usize, ) -> Result<Vec<LlmRequestRecord>, Error>

Get all LLM requests (for debugging)

pub fn record_structural_digest( &self, record: &StructuralDigestRecord, ) -> Result<(), Error>

Record a structural digest

pub fn get_structural_digests( &self, session_id: &str, node_id: &str, ) -> Result<Vec<StructuralDigestRecord>, Error>

Get structural digests for a session and node

pub fn record_context_provenance( &self, record: &ContextProvenanceRecord, ) -> Result<(), Error>

Record context provenance for a node

pub fn get_context_provenance( &self, session_id: &str, node_id: &str, ) -> Result<Option<ContextProvenanceRecord>, Error>

Get context provenance for a session and node

pub fn record_escalation_report( &self, record: &EscalationReportRecord, ) -> Result<(), Error>

Record an escalation report

pub fn get_escalation_reports( &self, session_id: &str, ) -> Result<Vec<EscalationReportRecord>, Error>

Get escalation reports for a session

pub fn record_rewrite(&self, record: &RewriteRecordRow) -> Result<(), Error>

Record a local graph rewrite

pub fn get_rewrite_records( &self, session_id: &str, ) -> Result<Vec<RewriteRecordRow>, Error>

Get rewrite records for a session

pub fn record_sheaf_validation( &self, record: &SheafValidationRow, ) -> Result<(), Error>

Record a sheaf validation result

pub fn get_sheaf_validations( &self, session_id: &str, node_id: &str, ) -> Result<Vec<SheafValidationRow>, Error>

Get sheaf validation results for a session and node

pub fn record_provisional_branch( &self, record: &ProvisionalBranchRow, ) -> Result<(), Error>

Record a new provisional branch

pub fn update_branch_state( &self, branch_id: &str, new_state: &str, ) -> Result<(), Error>

Update a provisional branch state

pub fn get_provisional_branches( &self, session_id: &str, ) -> Result<Vec<ProvisionalBranchRow>, Error>

Get all provisional branches for a session

pub fn get_live_branches_for_parent( &self, session_id: &str, parent_node_id: &str, ) -> Result<Vec<ProvisionalBranchRow>, Error>

Get live (active/sealed) provisional branches depending on a parent node

pub fn flush_branches_for_parent( &self, session_id: &str, parent_node_id: &str, ) -> Result<Vec<String>, Error>

Mark all live branches for a parent as flushed

pub fn record_branch_lineage( &self, record: &BranchLineageRow, ) -> Result<(), Error>

Record a branch lineage edge

pub fn get_child_branches( &self, parent_branch_id: &str, ) -> Result<Vec<String>, Error>

Get child branch IDs for a parent branch

pub fn record_interface_seal( &self, record: &InterfaceSealRow, ) -> Result<(), Error>

Record an interface seal

pub fn get_interface_seals( &self, session_id: &str, node_id: &str, ) -> Result<Vec<InterfaceSealRow>, Error>

Get all interface seals for a node

pub fn has_interface_seals( &self, session_id: &str, node_id: &str, ) -> Result<bool, Error>

Check whether a node has any interface seals

pub fn record_branch_flush(&self, record: &BranchFlushRow) -> Result<(), Error>

Record a branch flush decision

pub fn get_branch_flushes( &self, session_id: &str, ) -> Result<Vec<BranchFlushRow>, Error>

Get all branch flush records for a session

pub fn get_latest_node_states( &self, session_id: &str, ) -> Result<Vec<NodeStateRecord>, Error>

Get the latest node state snapshot per node for a session (for resume reconstruction).

Returns at most one record per node_id, picking the most recently created row.

pub fn record_task_graph_edge( &self, record: &TaskGraphEdgeRow, ) -> Result<(), Error>

Record a task graph edge (parent→child dependency)

pub fn get_task_graph_edges( &self, session_id: &str, ) -> Result<Vec<TaskGraphEdgeRow>, Error>

Get all task graph edges for a session

pub fn get_children_of_node( &self, session_id: &str, parent_node_id: &str, ) -> Result<Vec<String>, Error>

Get child node IDs for a parent in a session’s task graph

pub fn record_review_outcome( &self, record: &ReviewOutcomeRow, ) -> Result<(), Error>

Record a review outcome (approval, rejection, edit request)

pub fn get_review_outcomes( &self, session_id: &str, node_id: &str, ) -> Result<Vec<ReviewOutcomeRow>, Error>

Get all review outcomes for a node

pub fn get_latest_review_outcome( &self, session_id: &str, node_id: &str, ) -> Result<Option<ReviewOutcomeRow>, Error>

Get the most recent review outcome for a node

pub fn get_all_review_outcomes( &self, session_id: &str, ) -> Result<Vec<ReviewOutcomeRow>, Error>

Get all review outcomes for a session (across all nodes).

pub fn record_verification_result( &self, record: &VerificationResultRow, ) -> Result<(), Error>

Record a verification result snapshot for a node

pub fn get_verification_result( &self, session_id: &str, node_id: &str, ) -> Result<Option<VerificationResultRow>, Error>

Get the latest verification result for a node

pub fn get_all_verification_results( &self, session_id: &str, ) -> Result<Vec<VerificationResultRow>, Error>

Get all verification results for a session (for status display)

pub fn record_artifact_bundle( &self, record: &ArtifactBundleRow, ) -> Result<(), Error>

Record an artifact bundle snapshot for a node

pub fn get_artifact_bundle( &self, session_id: &str, node_id: &str, ) -> Result<Option<ArtifactBundleRow>, Error>

Get the latest artifact bundle for a node