pub fn test_runner_for_plugin(
plugin_name: &str,
working_dir: PathBuf,
) -> Box<dyn TestRunnerTrait>Expand description
PSP-5: Factory function to create a test runner for a given plugin
pub fn test_runner_for_plugin(
plugin_name: &str,
working_dir: PathBuf,
) -> Box<dyn TestRunnerTrait>PSP-5: Factory function to create a test runner for a given plugin