pub struct ContextProvenance {
pub node_id: String,
pub context_package_id: String,
pub structural_digest_hashes: Vec<(String, [u8; 32])>,
pub summary_digest_hashes: Vec<(String, [u8; 32])>,
pub dependency_commit_hashes: Vec<(String, Vec<u8>)>,
pub included_file_count: usize,
pub total_bytes: usize,
pub created_at: i64,
}Expand description
PSP-5 Phase 3: Provenance record tracking what context was used
Records the hashes of all summaries, contracts, and dependency commits used to derive a node’s prompt context. This enables reproducibility: the same context package can be reconstructed from persisted state.
Fields
node_id: StringNode this provenance belongs to
context_package_id: StringContext package ID
structural_digest_hashes: Vec<(String, [u8; 32])>Structural digest ID → hash pairs used
summary_digest_hashes: Vec<(String, [u8; 32])>Summary digest ID → hash pairs used
dependency_commit_hashes: Vec<(String, Vec<u8>)>Dependency node → commit hash pairs
included_file_count: usizeNumber of raw files included
total_bytes: usizeTotal bytes in context package
created_at: i64When this provenance was recorded