pub struct RetryPolicy {
pub max_compilation_retries: usize,
pub max_tool_retries: usize,
pub max_review_rejections: usize,
pub compilation_failures: usize,
pub tool_failures: usize,
pub review_rejections: usize,
pub last_error_type: Option<ErrorType>,
}Expand description
Retry policy configuration per PSP-4 specification
Fields
max_compilation_retries: usizeMax retries for compilation errors (default: 3)
max_tool_retries: usizeMax retries for tool failures (default: 5)
max_review_rejections: usizeMax reviewer rejections before escalation (default: 3)
compilation_failures: usizeCurrent consecutive failures by type
tool_failures: usizereview_rejections: usizelast_error_type: Option<ErrorType>Last error type encountered
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
Sourcepub fn record_failure(&mut self, error_type: ErrorType)
pub fn record_failure(&mut self, error_type: ErrorType)
Record a failure of a specific type
Sourcepub fn reset_failures(&mut self, error_type: ErrorType)
pub fn reset_failures(&mut self, error_type: ErrorType)
Reset failures of a specific type (on success)
Sourcepub fn should_escalate(&self, error_type: ErrorType) -> bool
pub fn should_escalate(&self, error_type: ErrorType) -> bool
Check if we should escalate for a specific error type
Sourcepub fn any_exceeded(&self) -> bool
pub fn any_exceeded(&self) -> bool
Check if any error type has exceeded its limit
Sourcepub fn failure_count(&self, error_type: ErrorType) -> usize
pub fn failure_count(&self, error_type: ErrorType) -> usize
Get the current failure count for an error type
Sourcepub fn remaining_attempts(&self, error_type: ErrorType) -> usize
pub fn remaining_attempts(&self, error_type: ErrorType) -> usize
Get remaining attempts for an error type